@@ -1,8 +1,8 @@
 <?php
-/*
- * $Horde: nag/search.php,v 1.5.2.1 2002/03/19 02:06:20 chuck Exp $
+/**
+ * $Horde: nag/search.php,v 1.5.2.3 2003/01/03 12:48:45 jan Exp $
  *
- * Copyright 2001 Jon Parise <jon@horde.org>
+ * Copyright 2001-2003 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -11,7 +11,7 @@
 define('NAG_BASE', dirname(__FILE__));
 require_once NAG_BASE . '/lib/base.php';
 
-$title = 'Search';
+$title = _("Search");
 $js_onLoad = null;
 require NAG_TEMPLATES . '/common-header.inc';
 require NAG_BASE . '/menu.php';
@@ -20,5 +20,3 @@ require NAG_TEMPLATES . '/search/begin.inc';
 require NAG_TEMPLATES . '/search/search.inc';
 require NAG_TEMPLATES . '/search/end.inc';
 require NAG_TEMPLATES . '/common-footer.inc';
-
-?>
