@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: nag/view.php,v 1.14.2.4 2002/12/19 13:02:53 jan Exp $
+ * $Horde: nag/view.php,v 1.14.2.6 2003/01/05 02:57:52 jon Exp $
  *
- * Copyright 2001 Jon Parise <jon@horde.org>
+ * Copyright 2001-2003 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -52,6 +52,9 @@ if (!isset($tasks[$task_id])) {
     include NAG_TEMPLATES . '/view/no-task.inc';
 } else {
     include NAG_TEMPLATES . '/view/headers.inc';
+    if (!$print_view) {
+        require NAG_TEMPLATES . '/view/navbar.inc';
+    }
     include NAG_TEMPLATES . '/view/description.inc';
     if (!$print_view) {
         include NAG_TEMPLATES . '/view/navbar.inc';
